@@ -26,6 +26,13 @@ except ImportError:
     pass
 
 
+try:
+    from chaussette.backend import _eventlet
+    _backends['eventlet'] = _eventlet.Server
+except ImportError:
+    pass
+
+
 def register(name, server):
     _backends[name] = server
 
